/**
 * Highwire Article Nav
 *
 * Copyright (c) 2010-2011 Board of Trustees, Leland Stanford Jr. University
 * This software is open-source licensed under the GNU Public License Version 2 or later
 * The full license is available in the LICENSE.TXT file at the root of this repository
 */

(function ($) {
  Drupal.behaviors.highwire_article_nav = {
    attach: function (context, settings) {
      $('.highwire-article-nav', context).once('highwire-article-nav', function() {
        $wrapper = $(this);

        $('a', $wrapper).click(function() {
          $link = $(this);
          var panelTarget = $link.data('panel-ajax-tab');
          var href = $link.attr('href');

          if (panelTarget) {
            var $tabLink = $('a.panels-ajax-tab-tab[data-panel-name="' + panelTarget + '"]');

            // If we are on the current tab and we are clicking a anchor, just let it happen
            // If we on the current tab and it is not an anchor, then ignore it.
            if ($tabLink.parent().hasClass('active')) {
              if (href.substring(0, 1) === '#') {
                return true;
              }
              else {
                // Jump to the tab, but don't do anything else
                $('html, body').animate({
                  scrollTop: $tabLink.offset().top + 'px'
                }, 'fast');
                return false;
              }
            }
            // We need to trigger a tab change
            else {
              // If it's a link to the tab itself (and not a sub-component) then just trigger a click on the tab and jump to the tab
              if (href.substring(0, 1) != '#') {
                $tabLink.trigger('click');

                // Jump to the tab
                $('html, body').animate({
                  scrollTop: $tabLink.offset().top + 'px'
                }, 'fast');
              }
              // We need to trigger the panel-ajax-tab THEN we need to jump to the anchored content
              else {
                $tabLink.panels_ajax_tabs_trigger(function() {
                  $('html, body').animate({
                    scrollTop: $(href).offset().top + 'px'
                  }, 'fast');
                });
              }
              return false;
            }
          }
        });

        // Scrolling float
        if ($('ul, ol', $wrapper).data('highwire-float') == '1') {
          //Since we are calculating heights of elements below, should be done after all the elements are loaded
          $(window).load(function(e) {
            var $this_pane = $wrapper.parent().parent();
            var $pane_last = $this_pane.siblings().last();
            var pane_last_offset = $pane_last.offset();
            var pane_last_height = $pane_last.height();
            var threshold = parseInt(pane_last_offset.top) + parseInt(pane_last_height);
            var stored_position = $this_pane.css('position');
            var stored_top = $this_pane.css('top');
            var floated = false;
            var this_pane_height = $this_pane.height();
            var content_region_height = $('#section-content').height();
            var header_height = $('#section-header').height();
            var threshold_height = content_region_height + header_height;

            $(window).scroll(function(e) {
              var y_scroll_pos = window.pageYOffset;
              var currentLayout = Drupal.highwireResponsive.getCurrentLayout();

              if((y_scroll_pos < threshold) || (threshold_height < (this_pane_height + y_scroll_pos)) || (currentLayout == 'mobile')) {
                $this_pane.css('position', stored_position);
                $this_pane.css('top', stored_top);
                floated = false;
              }
              else if(y_scroll_pos > pane_last_offset.top && floated === false) {
                $this_pane.hide();
                $this_pane.css('position', 'fixed');
                $this_pane.css('top', '20px');
                $this_pane.fadeIn('slow');
                floated = true;
              }
            });
          });
        }
      });
    }
  };
})(jQuery);
